@@ -17,7 +17,10 @@ def _get_feature_definition_paths(feature_definition_paths: List[str]) -> List[s
 
     paths = []
     for path in feature_definition_paths:
-        paths.extend(glob(path, recursive=True))
+        files = glob(path, recursive=True)
+        if not files:
+            raise FileNotFoundError(f"No such files: '{path}'")
+        paths.extend(files)
     return paths
 
 
@@ -28,11 +31,17 @@ def package(args: Namespace) -> None:
     feature_definitions: List[str] = _get_feature_definition_paths(args.feature_definitions)
     lock_controller: bool = args.lock_controller
     auth_features: bool = args.auth_features
+    for_git_repo: bool = args.git
 
     features = [Feature(open(fdl_file).read()) for fdl_file in sorted(feature_definitions)]
     generator = CodeGenerator(overwrite=overwrite)
     generator.generate_package(
-        package_name, features, out_dir, lock_controller=lock_controller, auth_features=auth_features
+        package_name,
+        features,
+        out_dir,
+        lock_controller=lock_controller,
+        auth_features=auth_features,
+        for_git_repo=for_git_repo,
     )
     generator.format_generated_files()
 
@@ -126,6 +135,7 @@ def main(argv: Optional[List[str]] = None) -> int:
     package_parser.add_argument("-n", "--package-name", help="Package name")
     package_parser.add_argument("-o", "--output-dir", default=".", help="Package directory (will contain 'setup.py')")
     package_parser.add_argument("--overwrite", action="store_true", help="Overwrite existing files")
+    package_parser.add_argument("--git", action="store_true", help="Generate .gitignore and README.md")
     package_parser.add_argument(
         "--lock-controller", action="store_true", help="Add default implementation of the core feature LockController"
     )
