@@ -167,15 +167,20 @@ class SilaServer:
         self.running = True
 
     def stop(self, grace_period: Optional[float] = None):
-        stop_event = self.grpc_server.stop(grace_period)
+        # stop zeroconf broadcasting
         for info in self.running_instances:
             self.service_broadcaster.unregister_server(info)
             self.running_instances.remove(info)
+
+        # stop feature implementations
         for servicer in self.feature_servicers.values():
             servicer.cancel_all_subscriptions()
             servicer.implementation.stop()
         self.child_task_executor.shutdown(wait=True)
-        stop_event.wait()
+
+        # stop grpc server
+        self.grpc_server.stop(grace_period).wait()
+
         self.running = False
 
     def __getitem__(self, item: str) -> Feature:
